@@ -19,11 +19,11 @@ class SubscriptionsApi(BaseApi):
 
         Creates a subscription for a customer to a subscription plan.
         If you provide a card on file in the request, Square charges the card
-        for 
+        for
         the subscription. Otherwise, Square bills an invoice to the customer's
-        email 
+        email
         address. The subscription starts immediately, unless the request
-        includes 
+        includes
         the optional `start_date`. Each individual subscription is associated
         with a particular location.
 
@@ -73,20 +73,20 @@ class SubscriptionsApi(BaseApi):
                              body):
         """Does a POST request to /v2/subscriptions/search.
 
-        Searches for subscriptions. 
+        Searches for subscriptions.
         Results are ordered chronologically by subscription creation date. If
-        the request specifies more than one location ID, 
-        the endpoint orders the result 
+        the request specifies more than one location ID,
+        the endpoint orders the result
         by location ID, and then by creation date within each location. If no
         locations are given
         in the query, all locations are searched.
         You can also optionally specify `customer_ids` to search by customer.
-                If left unset, all customers 
-        associated with the specified locations are returned. 
-        If the request specifies customer IDs, the endpoint orders results 
-        first by location, within location by customer ID, and within 
+        If left unset, all customers
+        associated with the specified locations are returned.
+        If the request specifies customer IDs, the endpoint orders results
+        first by location, within location by customer ID, and within
         customer by subscription creation date.
-        For more information, see 
+        For more information, see
         [Retrieve
         subscriptions](https://developer.squareup.com/docs/subscriptions-api/ov
         erview#retrieve-subscriptions).
@@ -186,7 +186,7 @@ class SubscriptionsApi(BaseApi):
                             body):
         """Does a PUT request to /v2/subscriptions/{subscription_id}.
 
-        Updates a subscription. You can set, modify, and clear the 
+        Updates a subscription. You can set, modify, and clear the
         `subscription` field values.
 
         Args:
@@ -306,7 +306,7 @@ class SubscriptionsApi(BaseApi):
                 [Pagination](https://developer.squareup.com/docs/working-with-a
                 pis/pagination).
             limit (int, optional): The upper limit on the number of
-                subscription events to return  in the response.   Default:
+                subscription events to return in the response.  Default:
                 `200`
 
         Returns:
@@ -355,3 +355,51 @@ class SubscriptionsApi(BaseApi):
             _errors = None
         _result = ApiResponse(_response, body=decoded, errors=_errors)
         return _result
+
+    def resume_subscription(self,
+                            subscription_id):
+        """Does a POST request to /v2/subscriptions/{subscription_id}/resume.
+
+        Resumes a deactivated subscription.
+
+        Args:
+            subscription_id (string): The ID of the subscription to resume.
+
+        Returns:
+            ApiResponse: An object with the response value as well as other
+                useful information such as status codes and headers. Success
+
+        Raises:
+            APIException: When an error occurs while fetching the data from
+                the remote API. This exception includes the HTTP Response
+                code, an error message, and the HTTP body that was received in
+                the request.
+
+        """
+
+        # Prepare query URL
+        _url_path = '/v2/subscriptions/{subscription_id}/resume'
+        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
+            'subscription_id': {'value': subscription_id, 'encode': True}
+        })
+        _query_builder = self.config.get_base_uri()
+        _query_builder += _url_path
+        _query_url = APIHelper.clean_url(_query_builder)
+
+        # Prepare headers
+        _headers = {
+            'accept': 'application/json'
+        }
+
+        # Prepare and execute request
+        _request = self.config.http_client.post(_query_url, headers=_headers)
+        OAuth2.apply(self.config, _request)
+        _response = self.execute_request(_request)
+
+        decoded = APIHelper.json_deserialize(_response.text)
+        if type(decoded) is dict:
+            _errors = decoded.get('errors')
+        else:
+            _errors = None
+        _result = ApiResponse(_response, body=decoded, errors=_errors)
+        return _result
